@@ -6,13 +6,19 @@ from pymasmovil.errors.exceptions import NewLineRequestRequiredParamsError
 
 class OrderItem(Contract):
 
-    _route = '/v0'
+    _route = '/v0/order-items'
     orderType = ''
     lastModifiedDate = ''
 
     def __init__(self, **kwargs):
         super().__init__(**kwargs)
 
+    @classmethod
+    def get(cls, session, order_item_id):
+        contract = super().get(session, order_item_id)
+
+        return cls(**contract['orderDetail'])
+
     @classmethod
     def create(cls, session, account, **new_order_item):
         """
@@ -23,7 +29,7 @@ class OrderItem(Contract):
             :return: order-item instance
         """
 
-        post_route = '{}/accounts/{}/order-items'.format(cls._route, account.id)
+        post_route = '/v0/accounts/{}/order-items'.format(account.id)
 
         cls._check_required_attributes(new_order_item)
 
